[Python-checkins] r84570 - python/branches/py3k/Lib/_pyio.py

amaury.forgeotdarc python-checkins at python.org
Tue Sep 7 00:23:13 CEST 2010


Author: amaury.forgeotdarc
Date: Tue Sep  7 00:23:13 2010
New Revision: 84570

Log:
Change docstrings to match the implementation


Modified:
   python/branches/py3k/Lib/_pyio.py

Modified: python/branches/py3k/Lib/_pyio.py
==============================================================================
--- python/branches/py3k/Lib/_pyio.py	(original)
+++ python/branches/py3k/Lib/_pyio.py	Tue Sep  7 00:23:13 2010
@@ -358,13 +358,13 @@
     def seekable(self) -> bool:
         """Return whether object supports random access.
 
-        If False, seek(), tell() and truncate() will raise IOError.
+        If False, seek(), tell() and truncate() will raise UnsupportedOperation.
         This method may need to do a test seek().
         """
         return False
 
     def _checkSeekable(self, msg=None):
         """Internal: raise an IOError if file is not seekable
         """
         if not self.seekable():
             raise UnsupportedOperation("File or stream is not seekable."
@@ -373,12 +373,12 @@
     def readable(self) -> bool:
         """Return whether object was opened for reading.
 
-        If False, read() will raise IOError.
+        If False, read() will raise UnsupportedOperation.
         """
         return False
 
     def _checkReadable(self, msg=None):
         """Internal: raise an IOError if file is not readable
         """
         if not self.readable():
             raise UnsupportedOperation("File or stream is not readable."
@@ -387,12 +387,12 @@
     def writable(self) -> bool:
         """Return whether object was opened for writing.
 
-        If False, write() and truncate() will raise IOError.
+        If False, write() and truncate() will raise UnsupportedOperation.
         """
         return False
 
     def _checkWritable(self, msg=None):
         """Internal: raise an IOError if file is not writable
         """
         if not self.writable():
             raise UnsupportedOperation("File or stream is not writable."
@@ -358,13 +358,13 @@
 
     def _checkSeekable(self, msg=None):
-        """Internal: raise an IOError if file is not seekable
+        """Internal: raise UnsupportedOperation if file is not seekable
         """
         if not self.seekable():
@@ -373,12 +373,12 @@
 
     def _checkReadable(self, msg=None):
-        """Internal: raise an IOError if file is not readable
+        """Internal: raise UnsupportedOperation if file is not readable
         """
         if not self.readable():
@@ -387,12 +387,12 @@
 
     def _checkWritable(self, msg=None):
-        """Internal: raise an IOError if file is not writable
+        """Internal: raise UnsupportedOperation if file is not writable
         """
         if not self.writable():


More information about the Python-checkins mailing list